@@ -11,10 +11,10 @@ import time
 from typing import List, Optional
 from PyQt6 import QtGui, QtCore
 from PyQt6.QtCore import Qt, QTimer, pyqtSlot, QRunnable, QThreadPool
-from PyQt6.QtGui import QAction
+from PyQt6.QtGui import QAction, QGuiApplication
 from PyQt6.QtWidgets import QApplication, QMainWindow, QTabWidget, QWidget, QLabel, \
     QVBoxLayout, QGridLayout, QLineEdit, QPushButton, QComboBox, QGroupBox, \
-    QCheckBox, QSystemTrayIcon, QMenu, QMessageBox, QSpinBox, QTextBrowser, QHBoxLayout
+    QCheckBox, QSystemTrayIcon, QMenu, QScrollArea, QMessageBox, QSpinBox, QTextBrowser, QHBoxLayout
 # Make it possible to run without installation
 # pylint: disable=# pylint: disable=wrong-import-position
 sys.path.insert(0, os.path.dirname(__file__) + "/..")
@@ -1063,9 +1063,9 @@ class FanCurveTab(QWidget):
         self.layout.addWidget(self.ic_upper_temp_label, 8, 0)
         self.layout.addWidget(self.accel_label, 9, 0)
         self.layout.addWidget(self.decel_label, 10, 0)
-        self.layout.addWidget(self.minfancurve_check, 11, 0)
-        self.layout.addWidget(self.lockfancontroller_check, 12, 0)
-        self.layout.addWidget(self.maximumfanspeed_check, 13, 0)
+        self.layout.addWidget(self.minfancurve_check, 11, 0, 1, 10)
+        self.layout.addWidget(self.lockfancontroller_check, 12, 0, 1, 10)
+        self.layout.addWidget(self.maximumfanspeed_check, 13, 0, 1, 10)
         for i in range(1, 11):
             self.create_fancurve_entry_view(self.layout, i)
         self.fancurve_group.setLayout(self.layout)
@@ -1110,6 +1110,7 @@ class FanCurveTab(QWidget):
             "the driver is not loaded properly or hwmon directory not found.\nIf features are marked "
             "red, an unexpected error has occured while accessing the hardware and you should notify the maintainer.")
         self.note_label2.setStyleSheet("color: red;")
+        self.note_label2.setWordWrap(True)
         self.main_layout.addWidget(self.note_label2, 3)
 
         self.setLayout(self.main_layout)
@@ -1285,6 +1286,7 @@ class OtherOptionsTab(QWidget):
             "It is recommended to customize the power settings only in custom mode. Although "
             "it is possible to change them in any mode.")
         self.power_note_label.setStyleSheet("color: red;")
+        self.power_note_label.setWordWrap(True)
         self.power_all_layout.addWidget(self.power_note_label)
 
 
@@ -1343,6 +1345,13 @@ class AutomationTab(QWidget):
             'These are Experimental Features.\n To apply and save the Settings Press "Save" or "Save and Quit"')
         self.options_layout.addWidget(self.note_label, 4)
 
+        self.note_openrc_label = QLabel(
+            "OpenRC service are available but need to be enable manually!\n"
+            "They are install automatically on gentoo base distro!\n"
+            "To get the files go to extra/service in the repo.\n"
+        )
+        self.options_layout.addWidget(self.note_openrc_label, 4)
+
         self.note_label2 = QLabel("")
 
         self.main_layout = QVBoxLayout()
@@ -1391,18 +1400,19 @@ class Tabs(QTabWidget):
         self.controller.tabs = self
 
         # setup tabs
-        self.fan_curve_tab = FanCurveTab(controller)
-        self.other_options_tab = OtherOptionsTab(controller)
-        self.automation_tab = AutomationTab(controller)
-        self.log_tab = LogTab(controller)
-        self.about_tab = AboutTab(controller)
+        self.tabs = (
+            ("Fan Curve", FanCurveTab(controller)),
+            ("Other Options", OtherOptionsTab(controller)),
+            ("Automation", AutomationTab(controller)),
+            ("Log", LogTab(controller)),
+            ("About", AboutTab(controller))
+        )
 
-        # tabs
-        self.addTab(self.fan_curve_tab, "Fan Curve")
-        self.addTab(self.other_options_tab, "Other Options")
-        self.addTab(self.automation_tab, "Automation")
-        self.addTab(self.log_tab, "Log")
-        self.addTab(self.about_tab, "About")
+        for tab_name, tab in self.tabs:
+            area = QScrollArea()
+            area.setWidget(tab)
+            area.setWidgetResizable(True)
+            self.addTab(area, tab_name)
 
 
 class QClickLabel(QLabel):
@@ -1424,6 +1434,9 @@ class MainWindow(QMainWindow):
         self.controller = controller
         self.controller.main_window = self
 
+        # Set a minium width to the window
+        self.setMinimumSize(1250, 725)
+
         # window layout
         self.setWindowTitle("LenovoLegionLinux")
         self.icon = icon
@@ -1454,12 +1467,14 @@ class MainWindow(QMainWindow):
         # main layout
         self.main_layout = QVBoxLayout()
         self.main_layout.addWidget(self.header_msg)
-        self.main_layout.addWidget(self.tabs)
+        self.main_layout.addWidget(self.tabs, 1)
         self.main_layout.addLayout(self.button_layout)
 
         # use main layout for main window
         self.main_widget = QWidget()
         self.main_widget.setLayout(self.main_layout)
+
+        # set main widget
         self.setCentralWidget(self.main_widget)
 
         # display of root warning message
@@ -1648,6 +1663,10 @@ def get_icon_path(controller):
     return icon_path
 
 def main():
+    # Set the desktop file name
+    # This make the window icon appear on wayland
+    QGuiApplication.setDesktopFileName("legion_gui.desktop")
+
     app = QApplication(sys.argv)
 
     use_legion_cli_to_write = '--use_legion_cli_to_write' in sys.argv
@@ -1681,6 +1700,11 @@ def main():
     # Resources
     icon_path = get_icon_path(controller)
     icon = QtGui.QIcon(icon_path)
+    # Set tray icon to the window icon
+    # Can't be use since tray icon is a svg
+    # Only support png and ico
+    # (maybe if PyQT6 introduce svg support)
+    #QGuiApplication.setWindowIcon(icon)
 
     # Main Windows
     main_window = MainWindow(controller, icon)
